package com.hello2morrow.sonargraph.core.controller.system

import com.hello2morrow.foundation.utilities.TemplateUtility

import de.schlichtherle.truezip.file.TFile

public abstract class MSBuildExecutor
{
    private final TFile m_projectFile;
    private final TFile m_solutionDir;

    public MSBuildExecutor(TFile projectFile, TFile solutionDir)
    {
        assert projectFile != null : "Parameter 'projectFile' must not be null"
        assert projectFile.canRead() : "No permission to read '" + projectFile.getAbsolutePath() + "' of method 'CPlusPlusMSBuildExecutor'"

        m_projectFile = projectFile;
        m_solutionDir = solutionDir;
    }

    protected TFile getProjectFile()
    {
        return m_projectFile
    }

    protected TFile getSolutionDir()
    {
        return m_solutionDir;
    }

    protected abstract String getTemplateName()

    protected abstract String getWrapperFileName()

    protected TFile writeProjectWrapper()
    {
        InputStream s = getClass().getClassLoader().getResourceAsStream(getTemplateName())
        TFile projectWrapperFile = new TFile(m_projectFile.getParentFile(), getWrapperFileName())
        StringWriter writer = new StringWriter()

        writer << s
        s.close()

        String template = writer.toString()
        def props = getProperties();

        if (projectWrapperFile.exists())
        {
            projectWrapperFile.rm()
        }
        projectWrapperFile << TemplateUtility.expandTemplateText(writer.toString(), props)

        return projectWrapperFile
    }

    protected Map<String, String> getProperties()
    {
        return [proj: m_projectFile.name];
    }
}